All Classes and Interfaces
Class
Description
An AWS Arn.
The forecast value for a specific date.
Link between an endpoint property and the
AwsEndpointAttribute it represents.
Provides information about a forecast.
Service client for accessing Amazon Forecast Query Service asynchronously.
A builder for creating an instance of
ForecastqueryAsyncClient.The parameters object used to resolve the auth schemes for the Forecastquery service.
A builder for a
ForecastqueryAuthSchemeParams.An auth scheme provider for Forecastquery service.
This includes configuration specific to Amazon Forecast Query Service that is supported by both
ForecastqueryClientBuilder and ForecastqueryAsyncClientBuilder.Service client for accessing Amazon Forecast Query Service.
A builder for creating an instance of
ForecastqueryClient.The parameters object used to resolve an endpoint for the Forecastquery service.
An endpoint provider for Forecastquery.
Class to expose the service client settings to the user.
A builder for creating a
ForecastqueryServiceClientConfigurationIdentifiers for variables declared within the rule engine, e.g.
The value is invalid or is too long.
The token is not valid.
The limit on the number of requests per second has been exceeded.
QueryForecastRequest MarshallerQueryWhatIfForecastRequest Marshaller
The specified resource is in use.
We can't find that resource.
Represents a URL to be used internally for endpoint resolution.
Base class for the types of values computable by the
RuleEngine.An array value.
A boolean value.
An integer value.
A record (map) value.
A string value.